@@ -16,6 +16,8 @@
 #define KSV_TOPWIDGET_H
 
 #include <kmainwindow.h>
+//Added by qt3to4:
+#include <QCloseEvent>
 
 class QCheckBox;
 
